@@ -1,6 +1,6 @@
 
 #
-# Copyright (c) 2013 - 2016 MasterCard International Incorporated
+# Copyright (c) 2013 - 2020 MasterCard International Incorporated
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without modification, are 
@@ -33,7 +33,7 @@ class Domain:
     def __init__(self, values = None):
         if values is None:
             values = {}
-        for key, value in values.iteritems():
+        for key, value in list(values.items()):
             self.__dict__[key] = build_payment_object(key, value)
 
         if "id" in self.__dict__:
@@ -49,7 +49,7 @@ class Domain:
     def to_dict(self):
 
         d = dict()
-        for key, value in self.__dict__.iteritems():
+        for key, value in list(self.__dict__.items()):
             if isinstance(value, Domain):
                 d[key] = value.to_dict()
             else:
